export declare enum WebSocketEvent {
    OPEN = "open",
    MESSAGE = "message",
    ERROR = "error",
    CLOSE = "close"
}
export declare enum WebSocketState {
    CONNECTING = 0,
    OPEN = 1,
    CLOSING = 2,
    CLOSED = 3
}
export declare enum WebSocketClosingCode {
    FORCE_CLOSE = 1001
}
export declare type SignalIndicator = string | number;
export declare type ShouldReconnect = (event: CloseEvent) => boolean;
export declare type Options<Req, Res, Err = string, SReq = Req, DRes = Res> = {
    url: string;
    getResponseIndicator: (res: Res) => SignalIndicator;
    getError: (res: Res) => Err | null;
    protocols?: string | string[];
    shouldReconnect?: ShouldReconnect | boolean;
    reconnectionInterval?: number | number[];
    serialize?: (req: Req) => SReq;
    deserialize?: (res: Res) => DRes;
    debug?: boolean;
};
export declare enum LogType {
    LOG = "log",
    ERROR = "error",
    WARNING = "warn"
}
export declare type SignalListenerData<DRes, Err> = {
    id: string;
    listener: SignalListener<DRes, Err>;
};
export declare type SignalListener<DRes, Err> = (error: Err | null, response: DRes) => void;
export declare type SignalListeners<DRes, Err> = {
    [signal in SignalIndicator]: SignalListenerData<DRes, Err>[];
};
export declare type OpenCallback = (event: Event) => void;
export declare type CloseCallback = (event: CloseEvent) => void;
